This package is python that show about Dusit.”
==============================================

PyPi: https://pypi.org/project/mynameisdusit/

Hello, this package show about Dusit, you can see for more information
via facebook.

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install mynameisdusit

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from mynameisdusit import UncleEngineer

   uncle = UncleEngineer() # show class
   uncle.show_name() # show name
   uncle.show_youtube() # show youtube link
   uncle.show_page() # show link page
   uncle.about() # show about Dusit
   uncle.show_art() # show ascii art

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer

YouTube: https://www.youtube.com/UncleEngineer
